@@ -671,7 +671,7 @@ def register(config, unused_plugins):
     # delete the true case of if block
     if config.update_registration:
         msg = ("Usage 'certbot register --update-registration' is deprecated.\n"
-               "Please use 'cerbot update_account [options]' instead.\n")
+               "Please use 'certbot update_account [options]' instead.\n")
         logger.warning(msg)
         return update_account(config, unused_plugins)
 
