@@ -4,7 +4,6 @@ import collections
 import errno
 import json
 import logging
-import os
 
 import six
 import zope.component
@@ -19,12 +18,12 @@ from certbot import achallenges  # pylint: disable=unused-import
 from certbot import cli
 from certbot import errors
 from certbot import interfaces
-from certbot.display import util as display_util
+from certbot.compat import os
 from certbot.display import ops
+from certbot.display import util as display_util
 from certbot.plugins import common
 from certbot.plugins import util
 
-
 logger = logging.getLogger(__name__)
 
 
@@ -225,7 +224,7 @@ to serve all files under specified web root ({0})."""
                 self.performed[root_path].remove(achall)
 
         not_removed = []  # type: List[str]
-        while len(self._created_dirs) > 0:
+        while self._created_dirs:
             path = self._created_dirs.pop()
             try:
                 os.rmdir(path)
